@@ -6,7 +6,7 @@ use Carp;
 use Scope::Guard qw(scope_guard);
 use Time::HiRes ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my $class = shift;
@@ -48,7 +48,7 @@ sub lock {
         Time::HiRes::sleep( $self->{interval} * rand(1) );
     }
 
-    return $rv ? ( $use_raii ? scope_guard { $self->release } : 1 ) : 0;
+    return $rv ? ( $use_raii ? scope_guard sub { $self->release } : 1 ) : 0;
 }
 
 sub release {
@@ -74,12 +74,14 @@ KeyedMutex::Memcached - An interprocess keyed mutex using memcached
   my $mutex = KeyedMutex::Memcached->new( cache => $cache );
 
   until ( my $value = $cache->get($key) ) {
-    if ( my $lock = $mutex->lock( $key, 1 ) ) {
-      #locked read from DB
-      $value = get_from_db($key);
-      $cache->set($key, $value);
-      last;
-    }
+    {
+      if ( my $lock = $mutex->lock( $key, 1 ) ) {
+        #locked read from DB
+        $value = get_from_db($key);
+        $cache->set($key, $value);
+        last;
+      }
+    };
   }
 
 =head1 DESCRIPTION
